@@ -10,7 +10,7 @@ def test_wheel_support_no_python_requires(mocker):
     wheel = get_embed_wheel("setuptools", for_py_version=None)
     zip_mock = mocker.MagicMock()
     mocker.patch("virtualenv.seed.wheels.util.ZipFile", new=zip_mock)
-    zip_mock.return_value.__enter__.return_value.read = lambda name: b""  # noqa: U100
+    zip_mock.return_value.__enter__.return_value.read = lambda name: b""  # noqa: ARG005
 
     supports = wheel.support_py("3.8")
     assert supports is True
